@@ -18,7 +18,6 @@
 Command-line interface to the OpenStack Nova API.
 """
 
-from __future__ import print_function
 import argparse
 import logging
 import sys
@@ -27,9 +26,6 @@ from keystoneauth1 import loading
 from oslo_utils import encodeutils
 from oslo_utils import importutils
 from oslo_utils import strutils
-import six
-
-osprofiler_profiler = importutils.try_import("osprofiler.profiler")
 
 import novaclient
 from novaclient import api_versions
@@ -39,6 +35,8 @@ import novaclient.extension
 from novaclient.i18n import _
 from novaclient import utils
 
+osprofiler_profiler = importutils.try_import("osprofiler.profiler")
+
 DEFAULT_MAJOR_OS_COMPUTE_API_VERSION = "2.0"
 # The default behaviour of nova client CLI is that CLI negotiates with server
 # to find out the most recent version between client and server, and
@@ -123,7 +121,7 @@ class DeprecatedAction(argparse.Action):
             # option
             self.real_action_args = False
             self.real_action = None
-        elif real_action is None or isinstance(real_action, six.string_types):
+        elif real_action is None or isinstance(real_action, str):
             # Specified by string (or None); we have to have a parser
             # to look up the actual action, so defer to later
             self.real_action_args = (option_strings, dest, help, kwargs)
@@ -249,11 +247,11 @@ class OpenStackComputeShell(object):
     def _append_global_identity_args(self, parser, argv):
         # Register the CLI arguments that have moved to the session object.
         loading.register_session_argparse_arguments(parser)
-        # Peek into argv to see if os-auth-token or os-token were given,
+        # Peek into argv to see if os-token was given,
         # in which case, the token auth plugin is what the user wants
         # else, we'll default to password
         default_auth_plugin = 'password'
-        if 'os-token' in argv:
+        if "--os-token" in argv:
             default_auth_plugin = 'token'
         loading.register_auth_argparse_arguments(
             parser, argv, default=default_auth_plugin)
@@ -270,6 +268,14 @@ class OpenStackComputeShell(object):
             'OS_PROJECT_NAME', 'OS_TENANT_NAME', 'NOVA_PROJECT_ID'))
         parser.set_defaults(os_project_id=utils.env(
             'OS_PROJECT_ID', 'OS_TENANT_ID'))
+        parser.set_defaults(
+            os_project_domain_id=utils.env('OS_PROJECT_DOMAIN_ID'))
+        parser.set_defaults(
+            os_project_domain_name=utils.env('OS_PROJECT_DOMAIN_NAME'))
+        parser.set_defaults(
+            os_user_domain_id=utils.env('OS_USER_DOMAIN_ID'))
+        parser.set_defaults(
+            os_user_domain_name=utils.env('OS_USER_DOMAIN_NAME'))
 
     def get_base_parser(self, argv):
         parser = NovaClientArgumentParser(
@@ -350,21 +356,14 @@ class OpenStackComputeShell(object):
                    '"X.latest", defaults to env[OS_COMPUTE_API_VERSION].'))
 
         parser.add_argument(
-            '--endpoint-override',
+            '--os-endpoint-override',
             metavar='<bypass-url>',
             dest='endpoint_override',
-            default=utils.env('NOVACLIENT_ENDPOINT_OVERRIDE',
+            default=utils.env('OS_ENDPOINT_OVERRIDE',
+                              'NOVACLIENT_ENDPOINT_OVERRIDE',
                               'NOVACLIENT_BYPASS_URL'),
             help=_("Use this API endpoint instead of the Service Catalog. "
-                   "Defaults to env[NOVACLIENT_ENDPOINT_OVERRIDE]."))
-
-        parser.add_argument(
-            '--bypass-url',
-            action=DeprecatedAction,
-            use=_('use "%s"; this option will be removed after Pike OpenStack '
-                  'release.') % '--os-endpoint-override',
-            dest='endpoint_override',
-            help=argparse.SUPPRESS)
+                   "Defaults to env[OS_ENDPOINT_OVERRIDE]."))
 
         if osprofiler_profiler:
             parser.add_argument('--profile',
@@ -442,6 +441,7 @@ class OpenStackComputeShell(object):
 
             action_help = desc.strip()
             arguments = getattr(callback, 'arguments', [])
+            groups = {}
 
             subparser = subparsers.add_parser(
                 command,
@@ -456,10 +456,14 @@ class OpenStackComputeShell(object):
             )
             self.subcommands[command] = subparser
             for (args, kwargs) in arguments:
-                start_version = kwargs.get("start_version", None)
+                kwargs = kwargs.copy()
+
+                start_version = kwargs.pop("start_version", None)
+                end_version = kwargs.pop("end_version", None)
+                group = kwargs.pop("group", None)
+
                 if start_version:
                     start_version = api_versions.APIVersion(start_version)
-                    end_version = kwargs.get("end_version", None)
                     if end_version:
                         end_version = api_versions.APIVersion(end_version)
                     else:
@@ -471,10 +475,16 @@ class OpenStackComputeShell(object):
                             "end": end_version.get_string()})
                     if not version.matches(start_version, end_version):
                         continue
-                kw = kwargs.copy()
-                kw.pop("start_version", None)
-                kw.pop("end_version", None)
-                subparser.add_argument(*args, **kw)
+
+                if group:
+                    if group not in groups:
+                        groups[group] = (
+                            subparser.add_mutually_exclusive_group()
+                        )
+                    kwargs['dest'] = kwargs.get('dest', group)
+                    groups[group].add_argument(*args, **kwargs)
+                else:
+                    subparser.add_argument(*args, **kwargs)
             subparser.set_defaults(func=callback)
 
     def setup_debugging(self, debug):
@@ -513,8 +523,10 @@ class OpenStackComputeShell(object):
             api_version = api_versions.get_api_version(
                 args.os_compute_api_version)
 
-        os_username = args.os_username
-        os_user_id = args.os_user_id
+        auth_token = getattr(args, "os_token", None)
+
+        os_username = getattr(args, "os_username", None)
+        os_user_id = getattr(args, "os_user_id", None)
         os_password = None  # Fetched and set later as needed
         os_project_name = getattr(
             args, 'os_project_name', getattr(args, 'os_tenant_name', None))
@@ -529,13 +541,16 @@ class OpenStackComputeShell(object):
             if (not args.os_project_domain_id and
                     not args.os_project_domain_name):
                 setattr(args, "os_project_domain_id", "default")
-            if not args.os_user_domain_id and not args.os_user_domain_name:
+
+            # os_user_domain_id is redundant in case of Token auth type
+            if not auth_token and (not args.os_user_domain_id and
+                                   not args.os_user_domain_name):
                 setattr(args, "os_user_domain_id", "default")
 
         os_project_domain_id = args.os_project_domain_id
         os_project_domain_name = args.os_project_domain_name
-        os_user_domain_id = args.os_project_domain_id
-        os_user_domain_name = args.os_project_domain_name
+        os_user_domain_id = getattr(args, "os_user_domain_id", None)
+        os_user_domain_name = getattr(args, "os_user_domain_name", None)
 
         endpoint_type = args.endpoint_type
         insecure = args.insecure
@@ -550,13 +565,6 @@ class OpenStackComputeShell(object):
         keystone_session = None
         keystone_auth = None
 
-        # We may have either, both or none of these.
-        # If we have both, we don't need USERNAME, PASSWORD etc.
-        # Finally, authenticate unless we have both.
-        # Note if we don't auth we probably don't have a tenant ID so we can't
-        # cache the token.
-        auth_token = getattr(args, 'os_token', None)
-
         if not endpoint_type:
             endpoint_type = DEFAULT_NOVA_ENDPOINT_TYPE
 
@@ -579,11 +587,11 @@ class OpenStackComputeShell(object):
         # for os_username or os_password but for compatibility it is not.
         if must_auth and not skip_auth:
 
-            if not os_username and not os_user_id:
+            if not any([auth_token, os_username, os_user_id]):
                 raise exc.CommandError(
-                    _("You must provide a username "
-                      "or user ID via --os-username, --os-user-id, "
-                      "env[OS_USERNAME] or env[OS_USER_ID]"))
+                    _("You must provide a user name/id (via --os-username, "
+                      "--os-user-id, env[OS_USERNAME] or env[OS_USER_ID]) or "
+                      "an auth token (via --os-token)."))
 
             if not any([os_project_name, os_project_id]):
                 raise exc.CommandError(_("You must provide a project name or"
@@ -598,6 +606,26 @@ class OpenStackComputeShell(object):
                     _("You must provide an auth url "
                       "via either --os-auth-url or env[OS_AUTH_URL]."))
 
+            # TODO(Shilpasd): need to provide support in python - novaclient
+            # for required options for below default auth type plugins:
+            # 1. v3oidcclientcredential
+            # 2. v3oidcpassword
+            # 3. v3oidcauthcode
+            # 4. v3oidcaccesstoken
+            # 5. v3oauth1
+            # 6. v3fedkerb
+            # 7. v3adfspassword
+            # 8. v3samlpassword
+            # 9. v3applicationcredential
+            # TODO(Shilpasd): need to provide support in python - novaclient
+            # for below extra keystoneauth auth type plugins:
+            # We will need to add code to support discovering of versions
+            # supported by the keystone service based on the auth_url similar
+            # to the one supported by glanceclient.
+            # 1. v3password
+            # 2. v3token
+            # 3. v3kerberos
+            # 4. v3totp
             with utils.record_time(self.times, args.timings,
                                    'auth_url', args.os_auth_url):
                 keystone_session = (
@@ -791,10 +819,7 @@ def main():
         OpenStackComputeShell().main(argv)
     except Exception as exc:
         logger.debug(exc, exc_info=1)
-        if six.PY2:
-            message = encodeutils.safe_encode(six.text_type(exc))
-        else:
-            message = encodeutils.exception_to_unicode(exc)
+        message = encodeutils.exception_to_unicode(exc)
         print("ERROR (%(type)s): %(msg)s" % {
               'type': exc.__class__.__name__,
               'msg': message},
