@@ -22,8 +22,6 @@ from novaclient.v2 import agents
 from novaclient.v2 import aggregates
 from novaclient.v2 import assisted_volume_snapshots
 from novaclient.v2 import availability_zones
-from novaclient.v2 import cells
-from novaclient.v2 import contrib
 from novaclient.v2 import flavor_access
 from novaclient.v2 import flavors
 from novaclient.v2 import hypervisors
@@ -32,7 +30,6 @@ from novaclient.v2 import instance_action
 from novaclient.v2 import instance_usage_audit_log
 from novaclient.v2 import keypairs
 from novaclient.v2 import limits
-from novaclient.v2 import list_extensions
 from novaclient.v2 import migrations
 from novaclient.v2 import networks
 from novaclient.v2 import quota_classes
@@ -168,11 +165,9 @@ class Client(object):
         #   deprecated now, which is why it is not initialized by default.
         self.assisted_volume_snapshots = \
             assisted_volume_snapshots.AssistedSnapshotManager(self)
-        self.cells = cells.CellsManager(self)
         self.instance_action = instance_action.InstanceActionManager(self)
         self.instance_usage_audit_log = \
             instance_usage_audit_log.InstanceUsageAuditLogManager(self)
-        self.list_extensions = list_extensions.ListExtManager(self)
         self.migrations = migrations.MigrationManager(self)
         self.server_external_events = \
             server_external_events.ServerExternalEventManager(self)
@@ -182,15 +177,6 @@ class Client(object):
         # Add in any extensions...
         if extensions:
             for extension in extensions:
-                # do not import extensions from contrib directory twice.
-                if extension.name in contrib.V2_0_EXTENSIONS:
-                    # NOTE(andreykurilin): this message looks more like
-                    #   warning or note, but it is not critical, so let's do
-                    #   not flood "warning" logging level and use just debug..
-                    self.logger.debug("Nova 2.0 extenstion '%s' is auto-loaded"
-                                      " by default. You do not need to specify"
-                                      " it manually.", extension.name)
-                    continue
                 if extension.manager_class:
                     setattr(self, extension.name,
                             extension.manager_class(self))
@@ -206,7 +192,7 @@ class Client(object):
             endpoint_type=endpoint_type,
             http_log_debug=http_log_debug,
             insecure=insecure,
-            logger=self.logger,
+            logger=logger,
             os_cache=self.os_cache,
             password=password,
             project_domain_id=project_domain_id,
@@ -233,50 +219,17 @@ class Client(object):
     def api_version(self, value):
         self.client.api_version = value
 
-    @property
-    def projectid(self):
-        self.logger.warning(_("Property 'projectid' is deprecated since "
-                              "Ocata. Use 'project_name' instead."))
-        return self.project_name
-
-    @property
-    def tenant_id(self):
-        self.logger.warning(_("Property 'tenant_id' is deprecated since "
-                              "Ocata. Use 'project_id' instead."))
-        return self.project_id
-
     def __enter__(self):
-        self.logger.warning(_("NovaClient instance can't be used as a "
-                              "context manager since Ocata (deprecated "
-                              "behaviour) since it is redundant in case of "
-                              "SessionClient."))
-        return self
+        raise exceptions.InvalidUsage(_(
+            "NovaClient instance can't be used as a context manager "
+            "since it is redundant in case of SessionClient."))
 
     def __exit__(self, t, v, tb):
         # do not do anything
         pass
 
-    def set_management_url(self, url):
-        self.logger.warning(
-            _("Method `set_management_url` is deprecated since Ocata. "
-              "Use `endpoint_override` argument instead while initializing "
-              "novaclient's instance."))
-        self.client.set_management_url(url)
-
     def get_timings(self):
         return self.client.get_timings()
 
     def reset_timings(self):
         self.client.reset_timings()
-
-    def authenticate(self):
-        """Authenticate against the server.
-
-        Normally this is called automatically when you first access the API,
-        but you can call this method to force authentication right now.
-
-        Returns on success; raises :exc:`exceptions.Unauthorized` if the
-        credentials are wrong.
-        """
-        self.logger.warning(_(
-            "Method 'authenticate' is deprecated since Ocata."))
